# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`tuned`](#tuned): Manage tuned configs and profiles

#### Private Classes

* `tuned::config`: Ensures tuned config files are up-to-date
* `tuned::install`: Install required packages
* `tuned::service`: Manage tuneD service

### Defined types

* [`tuned::profile`](#tuned--profile): A tuneD profile

### Data types

* [`Tuned::Config`](#Tuned--Config)
* [`Tuned::Main`](#Tuned--Main)

## Classes

### <a name="tuned"></a>`tuned`

Manage tuned configs and profiles

#### Examples

##### 

```puppet
include tuned
```

#### Parameters

The following parameters are available in the `tuned` class:

* [`enable`](#-tuned--enable)
* [`manage_package`](#-tuned--manage_package)
* [`manage_service`](#-tuned--manage_service)
* [`manage_dependencies`](#-tuned--manage_dependencies)
* [`package_ensure`](#-tuned--package_ensure)
* [`service_ensure`](#-tuned--service_ensure)
* [`service_name`](#-tuned--service_name)
* [`active_profile`](#-tuned--active_profile)
* [`packages`](#-tuned--packages)
* [`dependencies`](#-tuned--dependencies)
* [`main_config`](#-tuned--main_config)
* [`main`](#-tuned--main)
* [`profile`](#-tuned--profile)
* [`profiles_path`](#-tuned--profiles_path)
* [`profiles`](#-tuned--profiles)

##### <a name="-tuned--enable"></a>`enable`

Data type: `Boolean`

Whether OS tuning is enabled

##### <a name="-tuned--manage_package"></a>`manage_package`

Data type: `Boolean`

Whether tuned package should be managed.

##### <a name="-tuned--manage_service"></a>`manage_service`

Data type: `Boolean`

Whether service should be managed.

##### <a name="-tuned--manage_dependencies"></a>`manage_dependencies`

Data type: `Boolean`

Whether extra dependencies (might be used by plugins) should be installed.

##### <a name="-tuned--package_ensure"></a>`package_ensure`

Data type: `String`

Either specific version or `installed` | `present` | `latest`

##### <a name="-tuned--service_ensure"></a>`service_ensure`

Data type: `String`



##### <a name="-tuned--service_name"></a>`service_name`

Data type: `String`

Name of the service

##### <a name="-tuned--active_profile"></a>`active_profile`

Data type: `String[1]`

Name of the file containing curretly active profile (located in main config directory)

##### <a name="-tuned--packages"></a>`packages`

Data type: `Array[String[1]]`

Packages to be installed by this module.

##### <a name="-tuned--dependencies"></a>`dependencies`

Data type: `Array[String[1]]`

Extra packages required by plugins.

Default value: `[]`

##### <a name="-tuned--main_config"></a>`main_config`

Data type: `Stdlib::AbsolutePath`

Path to the tuned-main.conf file

##### <a name="-tuned--main"></a>`main`

Data type: `Tuned::Main`

Key-value configs to override tuned-main.conf

Default value: `{}`

##### <a name="-tuned--profile"></a>`profile`

Data type: `Optional[String]`

Currently active profile, if not set will be selected automatically.
Use `tuned-adm list` to see available profiles

Default value: `undef`

##### <a name="-tuned--profiles_path"></a>`profiles_path`

Data type: `Stdlib::AbsolutePath`

Path to profiles directory

##### <a name="-tuned--profiles"></a>`profiles`

Data type: `Hash`

Hash containing definition of custom profiles

Default value: `{}`

## Defined types

### <a name="tuned--profile"></a>`tuned::profile`

Manages profile config

#### Examples

##### 

```puppet
tuned::profile { 'high-performance': }
```

#### Parameters

The following parameters are available in the `tuned::profile` defined type:

* [`profile_name`](#-tuned--profile--profile_name)
* [`ensure`](#-tuned--profile--ensure)
* [`config`](#-tuned--profile--config)
* [`profiles_path`](#-tuned--profile--profiles_path)

##### <a name="-tuned--profile--profile_name"></a>`profile_name`

Data type: `Pattern[/^[\w\-]+$/]`

Name of the profile

Default value: `$title`

##### <a name="-tuned--profile--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `present`

##### <a name="-tuned--profile--config"></a>`config`

Data type: `Tuned::Config`

multi-level ini config with sections

Default value: `{}`

##### <a name="-tuned--profile--profiles_path"></a>`profiles_path`

Data type: `Stdlib::Absolutepath`

Path to profiles

Default value: `$tuned::profiles_path`

## Data types

### <a name="Tuned--Config"></a>`Tuned::Config`

The Tuned::Config data type.

Alias of

```puppet
Hash[String[1], Hash[
                        String[1], Variant[String, Numeric, Boolean]
                       ]]
```

### <a name="Tuned--Main"></a>`Tuned::Main`

The Tuned::Main data type.

Alias of `Hash[String[1], Variant[String, Numeric, Boolean]]`

